@@ -16,6 +16,28 @@
 
 from ansible.module_utils.basic import *  # noqa
 
+DOCUMENTATION = '''
+---
+module: warn
+short_description: Add warning to playbook output
+description:
+    - Add warning to playbook output
+options:
+    msg:
+        required: true
+        description:
+           - The warning text
+        type: str
+author: "Martin Andre (@mandre)"
+'''
+
+EXAMPLES = '''
+- hosts: webservers
+  tasks:
+  - name: Output warning message
+    warn: msg="Warning!"
+'''
+
 
 def main():
     module = AnsibleModule(argument_spec=dict(
